@@ -15,6 +15,15 @@
 #' @param lags Vector of lags, corresponding to the frequencies in the data.
 #' @param type The type of decomposition. If \code{"multiplicative"} is selected,
 #' then the logarithm of data is taken prior to the decomposition.
+#' @param smoother The type of function used in the smoother of the data to
+#' extract the trend and in seasonality smoothing. \code{smoother="ma"} relies
+#' on the centred moving average and will result in the classical decomposition.
+#' \code{smoother="lowess"} will use \link[stats]{lowess}, resulting in a
+#' decomposition similar to the STL (\link[stats]{stl}). Finally,
+#' \code{smoother="supsmu"} will use the Friedman's super smoother via
+#' \link[stats]{supsmu}.
+#' @param ... Other parameters passed to smoothers. Only works with
+#' lowess/supsmu.
 #'
 #' @return The object of the class "msdecompose" is return, containing:
 #' \itemize{
@@ -38,11 +47,13 @@
 #' plot(ourModel)
 #' plot(forecast(ourModel, model="AAN", h=12))
 #'
-#' @importFrom stats filter poly .lm.fit
+#' @importFrom stats filter poly .lm.fit supsmu
 #' @export msdecompose
-msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative")){
+msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative"),
+                        smoother=c("ma","lowess","supsmu"), ...){
     # Function decomposes time series, assuming multiple frequencies provided in lags
     type <- match.arg(type);
+    smoother <- match.arg(smoother);
 
     # paste0() is needed in order to avoid line breaks in the name
     yName <- paste0(deparse(substitute(y)),collapse="");
@@ -50,14 +61,36 @@ msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative")){
     # Remove the class
     y <- as.vector(y);
 
-    ma <- function(y, order){
-        if (order%%2 == 0){
-            weigths <- c(0.5, rep(1, order - 1), 0.5) / order;
+    seasonalLags <- any(lags>1);
+
+    smoothingFunction <- function(y, order=NULL, smoother="ma"){
+        if(smoother=="ma"){
+            # If this is just the global average, don't bother with odd/even
+            if((sum(!is.na(y))==order) || (order%%2 != 0)){
+                smoothWeigths <- rep(1, order) / order;
+            }
+            else{
+                smoothWeigths <- c(0.5, rep(1, order - 1), 0.5) / order;
+            }
+            return(filter(y[!is.na(y)], smoothWeigths))
         }
-        else {
-            weigths <- rep(1, order) / order;
+        else if(smoother=="lowess"){
+            # The default value of the smoother
+            if(is.null(order) || any(order==c(lags[lagsLength], obsInSample)) || order==1){
+                order <- 3/2;
+            }
+            return(lowess(y, f=1/order, ...)$y)
+        }
+        else if(smoother=="supsmu"){
+            # The default value of the smoother
+            if(!is.null(order) && any(order==c(lags[lagsLength], obsInSample)) || order==1){
+                span <- "cv";
+            }
+            else{
+                span <- 1/order;
+            }
+            return(supsmu(1:length(y), y, span=span, ...)$y)
         }
-        return(filter(y, weigths))
     }
 
     obsInSample <- length(y);
@@ -85,7 +118,7 @@ msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative")){
         rm(X)
     }
 
-    obs <- length(y);
+    obsInSample <- length(y);
     lags <- sort(unique(lags));
     lagsLength <- length(lags);
     # List of smoothed values
@@ -94,25 +127,44 @@ msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative")){
     ySmooth[[1]] <- yInsample;
     # List of cleared values
     yClear <- vector("list",lagsLength);
+
     # Smooth time series with different lags
     for(i in 1:lagsLength){
-        ySmooth[[i+1]] <- ma(yInsample,lags[i]);
+        ySmooth[[i+1]] <- smoothingFunction(yInsample,order=lags[i],smoother=smoother);
     }
     trend <- ySmooth[[lagsLength+1]];
 
     # Produce the cleared series
-    for(i in 1:lagsLength){
-        yClear[[i]] <- ySmooth[[i]] - ySmooth[[i+1]];
-    }
-
-    # The seasonal patterns
-    patterns <- vector("list",lagsLength);
-    for(i in 1:lagsLength){
-        patterns[[i]] <- vector("numeric",lags[i]);
-        for(j in 1:lags[i]){
-            patterns[[i]][j] <- mean(yClear[[i]][(1:(obs/lags[i])-1)*lags[i]+j],na.rm=TRUE);
+    # Do it only if there was a periodicity provided
+    if(seasonalLags){
+        for(i in 1:lagsLength){
+            yClear[[i]] <- ySmooth[[i]] - ySmooth[[i+1]];
         }
-        patterns[[i]][] <- patterns[[i]] - mean(patterns[[i]]);
+
+        # The seasonal patterns
+        patterns <- vector("list",lagsLength);
+        for(i in 1:lagsLength){
+            patterns[[i]] <- vector("numeric",obsInSample);
+            for(j in 1:lags[i]){
+                ySeasonal <- yClear[[i]][(1:ceiling(obsInSample/lags[i])-1)*lags[i]+j];
+                ySeasonalSmooth <- smoothingFunction(ySeasonal[!is.na(ySeasonal)],
+                                                     order=switch(smoother,
+                                                                  "ma"=length(ySeasonal[!is.na(ySeasonal)]),
+                                                                  obsInSample),
+                                                     smoother=smoother);
+                # In case of MA, only one value is returned
+                if(smoother=="ma"){
+                    patterns[[i]][(1:ceiling(obsInSample/lags[i])-1)*lags[i]+j] <- ySeasonalSmooth[!is.na(ySeasonalSmooth)];
+                }
+                else{
+                    patterns[[i]][(1:length(ySeasonalSmooth)-1)*lags[i]+j] <- ySeasonalSmooth;
+                }
+            }
+            patterns[[i]][] <- patterns[[i]] - mean(patterns[[i]], na.rm=TRUE);
+        }
+    }
+    else{
+        patterns <- NULL;
     }
 
     # Initial level and trend
@@ -126,15 +178,44 @@ msdecompose <- function(y, lags=c(12), type=c("additive","multiplicative")){
     if(type=="multiplicative"){
         initial[] <- exp(initial);
         trend <- exp(trend);
-        patterns[] <- lapply(patterns,exp);
+        if(seasonalLags){
+            patterns[] <- lapply(patterns,exp);
+        }
         if(shiftedData){
             initial[1] <- initial[1] - 1;
             trend[] <- trend -1;
         }
     }
 
-    return(structure(list(y=y, initial=initial, trend=trend, seasonal=patterns, loss="MSE",
-                          lags=lags, type=type, yName=yName), class=c("msdecompose","smooth")));
+    # Prepare the matrix of states
+    yFitted <- trend;
+    if(seasonalLags){
+        states <- cbind(trend, c(NA,diff(trend)), matrix(unlist(patterns)[1:obsInSample], obsInSample, lagsLength));
+        if(lagsLength>1){
+            colnames(states) <- c("level","trend",paste0("seasonal",1:lagsLength));
+        }
+        else{
+            colnames(states) <- c("level","trend","seasonal");
+        }
+        if(type=="additive"){
+            for(i in 1:length(lags)){
+                yFitted[] <- yFitted + rep(patterns[[i]],ceiling(obsInSample/lags[i]))[1:obsInSample];
+            }
+        }
+        else{
+            for(i in 1:length(lags)){
+                yFitted[] <- yFitted * rep(patterns[[i]],ceiling(obsInSample/lags[i]))[1:obsInSample];
+            }
+        }
+    }
+    else{
+        states <- cbind(trend, c(NA,diff(trend)));
+        colnames(states) <- c("level","trend");
+    }
+
+    return(structure(list(y=y, states=states, initial=initial, seasonal=patterns, fitted=yFitted,
+                          loss="MSE", lags=lags, type=type, yName=yName, smoother=smoother),
+                     class=c("msdecompose","smooth")));
 }
 
 #' @export
@@ -154,19 +235,7 @@ errorType.msdecompose <- function(object, ...){
 
 #' @export
 fitted.msdecompose <- function(object, ...){
-    yFitted <- object$trend;
-    obs <- nobs(object);
-    if(object$type=="additive"){
-        for(i in 1:length(object$lags)){
-            yFitted <- yFitted + rep(object$seasonal[[i]],ceiling(obs/object$lags[i]))[1:obs];
-        }
-    }
-    else{
-        for(i in 1:length(object$lags)){
-            yFitted <- yFitted * rep(object$seasonal[[i]],ceiling(obs/object$lags[i]))[1:obs];
-        }
-    }
-    return(yFitted);
+    return(object$fitted);
 }
 
 #' @aliases forecast forecast.smooth
@@ -186,17 +255,17 @@ forecast.msdecompose <- function(object, h=10,
                         "M"="YYY");
     }
 
-    obs <- nobs(object);
+    obsInSample <- nobs(object);
     yDeseasonalised <- actuals(object);
     yForecastStart <- time(yDeseasonalised)[length(time(yDeseasonalised))]+1/frequency(yDeseasonalised);
     if(errorType(object)=="A"){
         for(i in 1:length(object$lags)){
-            yDeseasonalised <- yDeseasonalised - rep(object$seasonal[[i]],ceiling(obs/object$lags[i]))[1:obs];
+            yDeseasonalised <- yDeseasonalised - rep(object$seasonal[[i]],ceiling(obsInSample/object$lags[i]))[1:obsInSample];
         }
     }
     else{
         for(i in 1:length(object$lags)){
-            yDeseasonalised <- yDeseasonalised / rep(object$seasonal[[i]],ceiling(obs/object$lags[i]))[1:obs];
+            yDeseasonalised <- yDeseasonalised / rep(object$seasonal[[i]],ceiling(obsInSample/object$lags[i]))[1:obsInSample];
         }
     }
     yesModel <- suppressWarnings(adam(yDeseasonalised,model=model,h=h,initial="b",...));
@@ -210,22 +279,24 @@ forecast.msdecompose <- function(object, h=10,
     else{
         lower <- upper <- NA;
     }
+
     # Add seasonality
+    #### This is correct for MA only. If we used another smoother, we should forecast seasonal pattern ####
     if(errorType(object)=="A"){
         for(i in 1:length(object$lags)){
-            yValues <- yValues + rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
+            yValues <- yValues + rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
             if(interval!="none"){
-                lower <- lower + rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
-                upper <- upper + rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
+                lower <- lower + rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
+                upper <- upper + rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
             }
         }
     }
     else{
         for(i in 1:length(object$lags)){
-            yValues <- yValues * rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
+            yValues <- yValues * rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
             if(interval!="none"){
-                lower <- lower * rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
-                upper <- upper * rep(object$seasonal[[i]],ceiling((obs+h)/object$lags[i]))[1:(obs+h)];
+                lower <- lower * rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
+                upper <- upper * rep(object$seasonal[[i]],ceiling((obsInSample+h)/object$lags[i]))[1:(obsInSample+h)];
             }
         }
     }
@@ -237,7 +308,7 @@ forecast.msdecompose <- function(object, h=10,
     }
 
     return(structure(list(model=object, esmodel=yesModel, method=paste0("ETS(",modelType(yesModel),") with decomposition"),
-                          mean=yForecast, forecast=yForecast, lower=lower, upper=upper,
+                          mean=yForecast, forecast=yForecast, lower=lower, upper=upper, side="both",
                           level=level, interval=interval),class=c("msdecompose.forecast","smooth.forecast","forecast")));
 }
 
@@ -279,7 +350,7 @@ plot.msdecompose <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
                              ask=prod(par("mfcol")) < length(which) && dev.interactive(),
                              lowess=TRUE, ...){
     ellipsis <- list(...);
-    obs <- nobs(x);
+    obsInSample <- nobs(x);
 
     # Define, whether to wait for the hit of "Enter"
     if(ask){
@@ -309,25 +380,29 @@ plot.msdecompose <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
     }
 
     if(any(which==12)){
-        yDecomposed <- cbind(actuals(x),x$trend);
-        for(i in 1:length(x$seasonal)){
-            yDecomposed <- cbind(yDecomposed,rep(x$seasonal[[i]],ceiling(obs/x$lags[i]))[1:obs]);
-        }
-        yDecomposed <- cbind(yDecomposed, residuals(x));
-        colnames(yDecomposed) <- c("Actuals","Trend",paste0("Seasonal ",c(1:length(x$seasonal))),"Residuals");
+        yDecomposed <- cbind(actuals(x), as.data.frame(x$states), residuals(x));
+        # for(i in 1:length(x$seasonal)){
+        #     yDecomposed <- cbind(yDecomposed,rep(x$seasonal[[i]],ceiling(obsInSample/x$lags[i]))[1:obsInSample]);
+        # }
+        # yDecomposed <- cbind(yDecomposed, residuals(x));
+        colnames(yDecomposed)[c(1,ncol(yDecomposed))] <- c("actuals","residuals");
 
         if(!any(names(ellipsis)=="main")){
             ellipsis$main <- paste0("Decomposition of ", x$yName);
         }
-        ellipsis$x <- yDecomposed;
+        if(ncol(x$states)<=5){
+            ellipsis$nc <- 1;
+        }
+        ellipsis$x <- ts(yDecomposed);
         do.call(plot,ellipsis);
     }
 }
 
 #' @export
 print.msdecompose <- function(x, ...){
-    cat(paste0("Multiple seasonal decomposition of ",x$yName," using c(",paste0(x$lags,collapse=","),") lags.\n"));
-    cat("Type of decomposition:",x$type);
+    cat(paste0("Multiple seasonal decomposition of ",x$yName," with c(",paste0(x$lags,collapse=","),") lags"));
+    cat("\nType of decomposition:",x$type);
+    cat("\nSmoother type:",x$smoother);
 }
 
 #' @export
